<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Fonts control
 */
class Kirhero_Fonts_Customizer_Control extends WP_Customize_Control {


	public $type = 'kirhero-fonts';

	/**
	 * Enqueue control related scripts/styles.
	 *
	 * @access public
	 */
	public function enqueue() {
		wp_enqueue_script( 'kirhero-select2', get_template_directory_uri() . '/inc/customizer/assets/js/select2.js', array( 'jquery' ), false, true );
		wp_enqueue_style( 'select2', get_template_directory_uri() . '/inc/customizer/assets/css/select2.css', null );
		wp_enqueue_script( 'kirhero-typographyjs', get_template_directory_uri() . '/inc/customizer/assets/js/typography.js', array( 'jquery', 'kirhero-select2' ), false, true );
		wp_enqueue_style( 'kirhero-fonts', get_template_directory_uri() . '/inc/customizer/assets/css/typography.css', null );
	}

	/**
	 * Render the control's content.
	 * Allows the content to be overriden without having to rewrite the wrapper in $this->render().
	 *
	 * @access protected
	 */
	protected function render_content() {
		$this_val = $this->value(); ?>
		<label>
			<?php if ( ! empty( $this->label ) ) : ?>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php endif; ?>
			<?php if ( ! empty( $this->description ) ) : ?>
				<span class="description customize-control-description"><?php echo wp_kses_post( $this->description ); ?></span>
			<?php endif; ?>

			<select class="kirhero-typography-select" <?php $this->link(); ?>>
				<option value="" <?php if ( ! $this_val ) echo 'selected="selected"'; ?>><?php esc_html_e( 'Default', 'orionwp' ); ?></option>
				<?php 

				// Get Standard font options
				if ( $std_fonts = kirhero_standard_fonts() ) { ?>
					<optgroup label="<?php esc_attr_e( 'Standard Fonts', 'orionwp' ); ?>">
						<?php
						// Loop through font options and add to select
						foreach ( $std_fonts as $font ) { ?>
							<option value="<?php echo esc_attr( $font ); ?>" <?php selected( $font, $this_val ); ?>><?php echo esc_html( $font ); ?></option>
						<?php } ?>
					</optgroup>
				<?php }

				// Google font options
				if ( $google_fonts = kirhero_google_fonts_array() ) { ?>
					<optgroup label="<?php esc_attr_e( 'Google Fonts', 'orionwp' ); ?>">
						<?php
						// Loop through font options and add to select
						foreach ( $google_fonts as $font ) { ?>
							<option value="<?php echo esc_attr( $font ); ?>" <?php selected( $font, $this_val ); ?>><?php echo esc_html( $font ); ?></option>
						<?php } ?>
					</optgroup>
				<?php } ?>
			</select>

		</label>

		<?php
	}
}
