<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Radio image control
 */
class Kirhero_Radio_Image_Customizer_Control extends WP_Customize_Control {

	/**
	 * The control type.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'kirhero-radio-image';

	/**
	 * Enqueue control related scripts/styles.
	 *
	 * @access public
	 */
	public function enqueue() {
		wp_enqueue_script( 'kirhero-radio-image', get_template_directory_uri() . '/inc/customizer/assets/js/radio-image.js', array( 'jquery', 'customize-base' ), false, true );
		wp_localize_script( 'kirhero-radio-image', 'kirheroL10n', $this->l10n() );
		wp_enqueue_style( 'kirhero-radio-image', get_template_directory_uri() . '/inc/customizer/assets/css/radio-image.css', null );
	}

	/**
	 * Refresh the parameters passed to the JavaScript via JSON.
	 *
	 * @see WP_Customize_Control::to_json()
	 */
	public function to_json() {
		parent::to_json();

		if ( isset( $this->default ) ) {
			$this->json['default'] 	= $this->default;
		} else {
			$this->json['default'] 	= $this->setting->default;
		}
		$this->json['value']       	= $this->value();
		$this->json['choices']     	= $this->choices;
		$this->json['link']        	= $this->get_link();
		$this->json['id']          	= $this->id;
		$this->json['l10n']    		= $this->l10n();

		$this->json['inputAttrs'] = '';
		foreach ( $this->input_attrs as $attr => $value ) {
			$this->json['inputAttrs'] .= $attr . '="' . esc_attr( $value ) . '" ';
		}

	}

	/**
	 * An Underscore (JS) template for this control's content (but not its container).
	 *
	 * Class variables for this control class are available in the `data` JS object;
	 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
	 *
	 * @see WP_Customize_Control::print_template()
	 *
	 * @access protected
	 */
	protected function content_template() {
		?>
		<# if ( data.label ) { #>
			<span class="customize-control-title">{{{ data.label }}}</span>
		<# } #>
		<# if ( data.description ) { #>
			<span class="description customize-control-description">{{{ data.description }}}</span>
		<# } #>
		<div id="input_{{ data.id }}" class="image">
			<# for ( key in data.choices ) { #>
				<input {{{ data.inputAttrs }}} class="image-select" type="radio" value="{{ key }}" name="_customize-radio-{{ data.id }}" id="{{ data.id }}{{ key }}" {{{ data.link }}}<# if ( data.value === key ) { #> checked="checked"<# } #>>
					<label for="{{ data.id }}{{ key }}" title="{{ data.l10n[ key ] }}">
						<img src="{{ data.choices[ key ] }}">
						<span class="image-clickable"></span>
					</label>
				</input>
			<# } #>
		</div>
		<?php
	}

	/**
	 * Returns an array of translation strings.
	 *
	 * @access protected
	 * @since 3.0.0
	 * @param string|false $id The string-ID.
	 * @return string
	 */
	protected function l10n( $id = false ) {
		$translation_strings = array(
			'content-sidebar' 	=> esc_attr__( 'Right Sidebar', 'orionwp' ),
			'sidebar-content' 		=> esc_attr__( 'Left Sidebar', 'orionwp' ),
			'full-width-content' 		=> esc_attr__( 'Full Width', 'orionwp' ),
			'both-sidebars' 		=> esc_attr__( 'Both Sidebar', 'orionwp' ),
		);
		if ( false === $id ) {
			return $translation_strings;
		}
		return $translation_strings[ $id ];
	}
}
