<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Only display for standard posts
if ( 'post' != get_post_type() ) {
	return;
}

// Text
$text = esc_html__( 'You Might Also Like', 'orionwp' );
// Apply filters for child theming
$text = apply_filters( 'kirhero_related_posts_title', $text );

// Number of columns for entries
$kirhero_columns = 3;

//218 x 150

// Query args
$args = array(
	'posts_per_page' => apply_filters( 'kirhero_related_blog_posts_count', $kirhero_columns ),
	'orderby'        => 'rand',
	'post__not_in'   => array( get_the_ID() ),
	'no_found_rows'  => true,
	'tax_query'      => array (
		'relation'  => 'AND',
		array (
			'taxonomy' => 'post_format',
			'field'    => 'slug',
			'terms'    => array( 'post-format-quote', 'post-format-link' ),
			'operator' => 'NOT IN',
		),
	),
);

// Args
$args = apply_filters( 'kirhero_blog_post_related_query_args', $args );

// Related query arguments
$kirhero_related_query = new WP_Query( $args );

// If the custom query returns post display related posts section
if ( $kirhero_related_query->have_posts() ) :

	// Wrapper classes
	$classes = 'related-posts';

	$kirhero_counters = 0;

	?>

	<?php do_action( 'kirhero_before_single_post_related_posts' ); ?>

	<section class="<?php echo esc_attr( $classes ); ?>">

		<h3 class="theme-heading related-posts-title">
			<span class="text"><?php echo esc_html( $text ); ?></span>
		</h3>

		<div class="kirhero-row">

			<?php foreach( $kirhero_related_query->posts as $post ) : setup_postdata( $post ); ?>

				<?php
					
					$kirhero_counters++;
					// Disable embeds
					$show_embeds = apply_filters( 'kirhero_related_blog_posts_embeds', true );
	
					// Get post format
					$format = get_post_format();
	
					// Add classes
					$classes	= array( 'related-post', 'one-third' );
					
					if($kirhero_counters == 1)
					{
						$classes[] = 'first';
					}
				
					?>

				<article <?php post_class( $classes ); ?>>

					<?php
					// Display post video
					if ( $show_embeds && 'video' == $format && $video = kirhero_get_post_video_html() ) : ?>

						<div class="related-post-video">
							<?php echo wp_kses_post($video); ?>
						</div><!-- .related-post-video -->

					<?php
					// Display post audio
					elseif ( $show_embeds && 'audio' == $format && $audio = kirhero_get_post_audio_html() ) : ?>

						<div class="related-post-video">
							<?php echo wp_kses_post($audio); ?>
						</div><!-- .related-post-audio -->

					<?php
					// Display post thumbnail
					elseif ( has_post_thumbnail() ) : ?>

						<figure class="related-post-media">

							<a href="<?php the_permalink(); ?>" class="related-thumb">

								<?php
									
								// Image args
								$img_args = array(
								    'alt' => get_the_title(),
								);
								
								if ( kirhero_schema_markup( 'image' ) ) {
									$img_args['itemprop'] = 'image';
								}
								
								// Display post thumbnail
								the_post_thumbnail( 'kirhero-medium', $img_args );
								
								?>

							</a>

						</figure>

					<?php endif; ?>

					<h3 class="related-post-title">
						<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a>
					</h3><!-- .related-post-title -->
									
				</article><!-- .related-post -->
				

			<?php endforeach; ?>

		</div>

	</section><!-- .related-posts -->

	<?php do_action( 'kirhero_after_single_post_related_posts' ); ?>

<?php endif; ?>

<?php wp_reset_postdata(); ?>